package com.op.mes.service;

import java.util.List;
import com.op.system.api.domain.SysUser;

/**
 * 用户 业务层
 *
 * @author OP
 */
public interface ISysUserService {
	/**
	 * 根据条件分页查询用户列表
	 *
	 * @param user 用户信息
	 * @return 用户信息集合信息
	 */
	public List<SysUser> selectUserList(SysUser user);

	/**
	 * 根据条件分页查询已分配用户角色列表
	 *
	 * @param user 用户信息
	 * @return 用户信息集合信息
	 */
	public List<SysUser> selectAllocatedList(SysUser user);

	/**
	 * 根据条件分页查询未分配用户角色列表
	 *
	 * @param user 用户信息
	 * @return 用户信息集合信息
	 */
	public List<SysUser> selectUnallocatedList(SysUser user);

	/**
	 * 通过用户名查询用户
	 *
	 * @param userName 用户名
	 * @return 用户对象信息
	 */
	public SysUser selectUserByUserName(String userName);

	/**
	 * 通过用户ID查询用户
	 *
	 * @param userId 用户ID
	 * @return 用户对象信息
	 */
	public SysUser selectUserById(Long userId);

	/**
	 * 校验用户名称是否唯一
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public boolean checkUserNameUnique(SysUser user);

	/**
	 * 校验手机号码是否唯一
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public boolean checkPhoneUnique(SysUser user);

	/**
	 * 校验email是否唯一
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public boolean checkEmailUnique(SysUser user);

	/**
	 * 校验用户是否允许操作
	 *
	 * @param user 用户信息
	 */
	public void checkUserAllowed(SysUser user);

	/**
	 * 校验用户是否有数据权限
	 *
	 * @param userId 用户id
	 */
	public void checkUserDataScope(Long userId);

	/**
	 * 新增用户信息
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public int insertUser(SysUser user);

	/**
	 * 注册用户信息
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public boolean registerUser(SysUser user);


	/**
	 * 修改用户状态
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public int updateUserStatus(SysUser user);

	/**
	 * 修改用户基本信息
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public int updateUserProfile(SysUser user);

	/**
	 * 修改用户头像
	 *
	 * @param userName 用户名
	 * @param avatar   头像地址
	 * @return 结果
	 */
	public boolean updateUserAvatar(String userName, String avatar);

	/**
	 * 重置用户密码
	 *
	 * @param user 用户信息
	 * @return 结果
	 */
	public int resetPwd(SysUser user);

	/**
	 * 重置用户密码
	 *
	 * @param userName 用户名
	 * @param password 密码
	 * @return 结果
	 */
	public int resetUserPwd(String userName, String password);

}
